@@ -102,6 +102,7 @@ class Linear(AbstractRegression):
         self._Beta = MatMul( MatMul(self._XtXinv, self._Xt, self.Axis), self._Y, self.Axis )
         self._computeFitStats()
         self._BetaFitError = self.Student * np.sqrt( MatDiag(self._XtXinv, tuple(reversed(self.Axis))) * self.MSE )
+        self._BetaPredictionError = self.Student * np.sqrt( MatDiag(self._XtXinv + 1, tuple(reversed(self.Axis))) * self.MSE )
 
     def Eval(self, x:NDArray) -> NDArray:
         """
@@ -172,6 +173,18 @@ class Linear(AbstractRegression):
         else:
             return self._BetaFitError
 
+    @property
+    def BetaPredictionError(self) -> NDArray:
+        """
+        The prediction error on the fit parameters. Not sure if this is legit yet, 
+        but I computed it in a similar way than what is used for the EvalPredictionError. 
+        """
+        if self._Rescale:
+            # Not sure if this is right, though! Will have to verify!
+            return MatMul(MatInv(MatMul(self._Omega, self._X, self.Axis), self.Axis), self._BetaPredictionError, self.Axis)
+        else:
+            return self._BetaPredictionError
+
     def _Scale(self, x:NDArray) -> NDArray:
         # Wraps the rescaling to have it in a one liner, including the replacing infs with 1.0
         temp = self._Scaler.Scale(x)
