@@ -1,18 +1,18 @@
 import numpy as np
 from typing import Tuple
 from .GenericCurveFit import GenericCurveFit
-from .utilities import FFTGuess
+from nptyping import NDArray
 
 class Logistic(GenericCurveFit):
     
-    def FitFunc(self, x:np.ndarray, a:float, b:float, c:float, d:float) -> np.ndarray:
+    def FitFunc(self, x:NDArray, a:float, b:float, c:float, d:float) -> NDArray:
         """
         An logistic function that goes like
         $$ y = \frac{a}{1 + e^{-b(x-c)}} + d $$
         """
         return a / (1 + np.exp(-b*(x-c))) + d
 
-    def Jacobian(self, x:np.ndarray, a:float, b:float, c:float, d:float) -> np.ndarray:
+    def Jacobian(self, x:NDArray, a:float, b:float, c:float, d:float) -> NDArray:
         """
         The jacobian of the exponential fit function. 
         Meant to return a matrix of shape [x.shape[0], 3], where
@@ -27,5 +27,5 @@ class Logistic(GenericCurveFit):
 
         return out
 
-    def __init__(self, x:np.ndarray, y:np.ndarray, p0:np.ndarray=None, bounds=(-np.inf, np.inf), confidenceInterval:float=0.95, simult:bool=False, **kwargs):
+    def __init__(self, x:NDArray, y:NDArray, p0:NDArray=None, bounds=(-np.inf, np.inf), confidenceInterval:float=0.95, simult:bool=False, **kwargs):
         super(Logistic, self).__init__(x, y, self.FitFunc, self.Jacobian, p0, bounds, confidenceInterval, simult, **kwargs )
\ No newline at end of file
