@@ -7,3 +7,5 @@ from .GenericCurveFit import GenericCurveFit
 from .CosineFit import CosineFit
 from .SystemIdentification import SystemIdentification
 from .Gaussian import Gaussian
+from .Ellipse import Ellipse
+from .JonckheereTerpstra import JonckheereTerpstra
\ No newline at end of file
